Attribute VB_Name = "Modul2"
' **********************************************************************
' * Makro erzeugt aus dem aktiven Zeichnungsdokument
' * eine DXF Datei im Verzeichnis der Zeichnung.
' * Quelle:
' * 05.04.2001 Stefan Berlitz (stefan.berlitz@solidworks.cad.de)
' * http://solidworks.cad.de
' * http://swtools.cad.de
' * gendert
' * 10.06.2005 Volkmar Grube (v.grube@gmx.de)
' **********************************************************************

Dim swApp As Object
Dim DrawingDoc As SldWorks.DrawingDoc
Dim Sheet As SldWorks.Sheet
Dim Titel, Kurzname As String
Dim Datei As String
Dim temp As String
Dim pfad, fname As String
Dim msgtxt As String

Dim i As Long
Dim AnzahlBl As Long
Dim SheetName As String

Const swDxfFormat_R12 = 0
Const swDxfFormat_R13 = 1
Const swDxfFormat_R14 = 2
Const swDxfFormat_R2000 = 3
Const swDxfFormat_R2004 = 4
Const swDocDRAWING = 3

Sub main_mit_Justieriung()
  DXFSpeichern (1)  ' R12 mit Justierung
End Sub

Sub main()
  DXFSpeichern (0)  ' R12-Format
End Sub

Sub main_R14()
  DXFSpeichern (2)  ' R14-Format
End Sub

Sub DXFSpeichern(Modus)
Dim OK As Boolean

    Set swApp = CreateObject("SldWorks.Application")
    Set DrawingDoc = swApp.ActiveDoc
    
    If (DrawingDoc.GetType <> swDocDRAWING) Then
        ' wenn keine Zeichnung aktiv wird das Makro wieder beendet
        MsgBox "Nur fr Zeichnungen geeignet"
        Exit Sub
    End If

    ' aktuelles Blatt und Blattname ermitteln
    Set Sheet = DrawingDoc.GetCurrentSheet
    
    SheetName = Sheet.GetName
    
    ' damit die DXF anschlieend im Verzeichnis der Zeichnung gespeichert werden
    ' muss der Pfad ermittelt werden. Ansonsten werden die DXFs im Verzeichnis
    ' des Makro gespeichert. Wenn man ein Sammelverzeichnis hat kann man das
    'natrlich auch einfach direkt angeben
    temp = DrawingDoc.GetPathName
    ' da wir nur den Pfad brauchen alles andere abtrennen
    For i = Len(temp) To 1 Step -1
        If Mid$(temp, i, 1) = "\" Then
            pfad = Left(temp, i)
            fname = Right(temp, Len(temp) - i)
            Exit For
        End If
    Next i
    
    ' Kurzname bilden
    Kurzname = LCase(fname)
    ' und die Endung mit dem .slddrw abschneiden, wenn vorhanden
    If (InStr(Kurzname, ".sld") > 0) Then
      Kurzname = Left(Kurzname, InStr(Kurzname, ".sld") - 1)
    Else
      Kurzname = Titel
    End If
    
    ' wenn der Blattname = "dxf", dann wird der Dateiname = Dokumentname
    ' wenn der Blattname mit "Blatt" beginnt, wird der Dateiname aus dem Dokumentnamen und dem Blattnamen gebildet
    ' die Zeichenkette "dxf" wird, falls vorhanden, im Blattnamen gegen den Dokumentnamen getauscht
    If UCase(SheetName) <> "DXF" Then
      If Left(SheetName, 5) = "Blatt" Then
        Datei = Kurzname + "_" + LCase(SheetName)
      Else
        Datei = Replace(SheetName, "dxf", Kurzname, 1, -1, vbTextCompare)
      End If
    Else
      Datei = Kurzname
    End If
    
    ' wir wollen das Blatt als DXF mit den eingestellten Optionen abspeichern
    Datei = pfad & Datei & ".dxf"
    
    ' Festlegung des DXF-Formates, fr gerichtete Dateien R12, alle anderen R14
    Select Case Modus
    Case 0   ' R12 ohne Justierung
      OK = swApp.SetUserPreferenceIntegerValue(swDxfVersion, swDxfFormat_R12)
    Case 1   ' R12 fr justierte DXF-Dateien
      OK = swApp.SetUserPreferenceIntegerValue(swDxfVersion, swDxfFormat_R12)
    Case 2   ' R14 ohne Justierung
      OK = swApp.SetUserPreferenceIntegerValue(swDxfVersion, swDxfFormat_R14)
    End Select
    
    ' dann erfolgt das Speichern, die Parameter sind:
    ' DrawingDoc.SaveAs2 ( newName, unused, saveAsCopy, silent )
    ' wenn alles geklappt hat, wird eine 0 zurckgeliefert, ansonsten ein
    ' Wert ungleich 0
      
    If (DrawingDoc.SaveAs2(Datei, 0, True, False)) Then
        MsgBox "FEHLER BEIM SPEICHERN VON " & Datei & Chr$(10) & Chr$(13)
        msgtxt = "*** FEHLER bei: " & Datei & Chr$(10) & Chr$(13)
    Else
'         msgtxt = msgtxt & "erfolgreich gespeichert: " & Datei & Chr$(10) & Chr$(13)
        msgtxt = "erfolgreich gespeichert: " & Datei & Chr$(10) & Chr$(13)
        If Modus = 1 Then
          Dim pathname As String
          pathname = swApp.GetCurrentMacroPathFolder

          Shell pathname & "\SW_DXF_Umwandlung.exe " & """" & Datei & """", vbNormalFocus
        End If
  End If
        
    ' und noch die Zusammenfassung bers Speichern ausgeben
    MsgBox msgtxt
End Sub

